This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "".
The branch, master has been updated
via 3600304c30c4a345538f6c06ca50183b14cd12b1 (commit)
via 4ec4a756c7607e3a78878e6699a82ccf6d0a1461 (commit)
from 0f700e1a4b8e66c269081eba64eb5be8c37de868 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commit 3600304c30c4a345538f6c06ca50183b14cd12b1
Author: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Date: Sat Apr 28 16:06:42 2018 +0300
doc: allow user to provide exta asciidoctor flags
Allow user to provide extra asciidoctor flags. E.g. this allows one to
override icons and/or fonts placement.
Signed-off-by: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Reviewed-by: Bill Fischofer <bill.fischofer(a)linaro.org>
Signed-off-by: Maxim Uvarov <maxim.uvarov(a)linaro.org>
diff --git a/doc/Makefile.inc b/doc/Makefile.inc
index 23703127..1732c355 100644
--- a/doc/Makefile.inc
+++ b/doc/Makefile.inc
@@ -13,4 +13,5 @@ SUFFIXES = .svg .msc .gv .html .adoc
.adoc.html:
asciidoctor $(ASCIIDOC_FLAGS) --out-file=$@ $<
-ASCIIDOC_FLAGS =-a data-uri -b html5 -a icons=font -a toc2
+ASCIIDOC_FLAGS =-a data-uri -b html5 -a icons=font -a toc2 \
+ $(EXTRA_ASCIIDOC_FLAGS)
commit 4ec4a756c7607e3a78878e6699a82ccf6d0a1461
Author: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Date: Sat Apr 28 10:57:32 2018 +0300
travis: do not run gcov before executing codecov script
There is no need to manually run gcov from Travis script, codecov.io
will do that for us.
Signed-off-by: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Reviewed-by: Bill Fischofer <bill.fischofer(a)linaro.org>
Signed-off-by: Maxim Uvarov <maxim.uvarov(a)linaro.org>
diff --git a/.travis.yml b/.travis.yml
index a6cce816..cb05b839 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -310,7 +310,7 @@ jobs:
- sudo CCACHE_DISABLE=1 ODP_SCHEDULER=sp LD_LIBRARY_PATH="$HOME/cunit-install/$CROSS_ARCH/lib:$LD_LIBRARY_PATH" make check
- sudo CCACHE_DISABLE=1 ODP_SCHEDULER=iquery LD_LIBRARY_PATH="$HOME/cunit-install/$CROSS_ARCH/lib:$LD_LIBRARY_PATH" make check
- sudo CCACHE_DISABLE=1 ODP_SCHEDULER=scalable LD_LIBRARY_PATH="$HOME/cunit-install/$CROSS_ARCH/lib:$LD_LIBRARY_PATH" make check
- - find . -type f -iname '*.[ch]' -not -path ".git/*" -execdir gcov {} \; ; bash <(curl -s https://codecov.io/bash) -X coveragepy
+ - bash <(curl -s https://codecov.io/bash) -X coveragepy
- stage: test
env: TEST=distcheck
compiler: gcc
-----------------------------------------------------------------------
Summary of changes:
.travis.yml | 2 +-
doc/Makefile.inc | 3 ++-
2 files changed, 3 insertions(+), 2 deletions(-)
hooks/post-receive
--
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "".
The branch, master has been updated
via 82499a9a4c80670de20825992478ccd4d764e28c (commit)
from c164ad605422f90f3566e4c4ebed0ea3c2adb3a8 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commit 82499a9a4c80670de20825992478ccd4d764e28c
Author: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Date: Sun Apr 22 23:49:15 2018 +0300
linux-gen: dpdk: fix linking to libnuma
Linking to dpdk/numa can fail with the following message:
/usr/bin/x86_64-linux-gnu-ld: lib/.libs/libodp-linux.a(dpdk.o):
undefined reference to symbol 'numa_num_configured_nodes@@libnuma_1.2'
//usr/lib/x86_64-linux-gnu/libnuma.so.1:
error adding symbols: DSO missing from command line
Signed-off-by: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Reviewed by: Bill Fischofer <bill.fischofer(a)linaro.org>
Signed-off-by: Maxim Uvarov <maxim.uvarov(a)linaro.org>
diff --git a/platform/linux-generic/m4/odp_dpdk.m4 b/platform/linux-generic/m4/odp_dpdk.m4
index cb2ed60d..09dde35a 100644
--- a/platform/linux-generic/m4/odp_dpdk.m4
+++ b/platform/linux-generic/m4/odp_dpdk.m4
@@ -40,6 +40,14 @@ then
;;
esac
+ OLD_LIBS=$LIBS
+ LIBS="-lnuma"
+ AC_TRY_LINK_FUNC([numa_num_configured_nodes],
+ [AC_DEFINE([HAVE_NUMA_LIBRARY], [1],
+ [Define to 1 if numa library is usable])
+ AS_VAR_APPEND([DPDK_LIBS_LIBODP], [" -lnuma"])])
+ LIBS=$OLD_LIBS
+
AC_DEFINE([ODP_PKTIO_DPDK], [1],
[Define to 1 to enable DPDK packet I/O support])
AC_DEFINE_UNQUOTED([ODP_DPDK_ZERO_COPY], [$zero_copy],
diff --git a/platform/linux-generic/pktio/dpdk.c b/platform/linux-generic/pktio/dpdk.c
index 0550416b..14d59d8e 100644
--- a/platform/linux-generic/pktio/dpdk.c
+++ b/platform/linux-generic/pktio/dpdk.c
@@ -50,7 +50,7 @@
#include <rte_version.h>
/* NUMA is not supported on all platforms */
-#ifdef RTE_EAL_NUMA_AWARE_HUGEPAGES
+#ifdef HAVE_NUMA_LIBRARY
#include <numa.h>
#else
#define numa_num_configured_nodes() 1
-----------------------------------------------------------------------
Summary of changes:
platform/linux-generic/m4/odp_dpdk.m4 | 8 ++++++++
platform/linux-generic/pktio/dpdk.c | 2 +-
2 files changed, 9 insertions(+), 1 deletion(-)
hooks/post-receive
--
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "".
The branch, master has been updated
via f69f033da3b6900acdd170668cae07ac6cd959f3 (commit)
via 8d957f16105fa44d483478b2c05bae735680c007 (commit)
via 5028177e4e795305b514d7164ff882dcf1d3622b (commit)
from 24262a9aae62290dfd1a041d0bd5c6943270251d (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commit f69f033da3b6900acdd170668cae07ac6cd959f3
Author: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Date: Tue Apr 24 17:39:17 2018 +0300
validation: crypto: add missing ODP_CIPHER_ALG_AES_CTR name
Signed-off-by: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Reviewed-by: Bill Fischofer <bill.fischofer(a)linaro.org>
Signed-off-by: Maxim Uvarov <maxim.uvarov(a)linaro.org>
diff --git a/test/validation/api/crypto/odp_crypto_test_inp.c b/test/validation/api/crypto/odp_crypto_test_inp.c
index 676b9b12..83070290 100644
--- a/test/validation/api/crypto/odp_crypto_test_inp.c
+++ b/test/validation/api/crypto/odp_crypto_test_inp.c
@@ -79,6 +79,8 @@ static const char *cipher_alg_name(odp_cipher_alg_t cipher)
return "ODP_CIPHER_ALG_3DES_CBC";
case ODP_CIPHER_ALG_AES_CBC:
return "ODP_CIPHER_ALG_AES_CBC";
+ case ODP_CIPHER_ALG_AES_CTR:
+ return "ODP_CIPHER_ALG_AES_CTR";
case ODP_CIPHER_ALG_AES_GCM:
return "ODP_CIPHER_ALG_AES_GCM";
case ODP_CIPHER_ALG_AES_CCM:
commit 8d957f16105fa44d483478b2c05bae735680c007
Author: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Date: Tue Apr 24 11:56:15 2018 +0300
travis: bump DPDK version to 17.11.2 - latest LTS release
Signed-off-by: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Reviewed-by: Matias Elo <matias.elo(a)nokia.com>
Signed-off-by: Maxim Uvarov <maxim.uvarov(a)linaro.org>
diff --git a/.travis.yml b/.travis.yml
index 70eff748..a6cce816 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -49,7 +49,7 @@ env:
# for individual commit validation. But you you want to track tests history
# you need generated new one at https://codecov.io specific for your repo.
- CODECOV_TOKEN=a733c34c-5f5c-4ff1-af4b-e9f5edb1ab5e
- - DPDK_VERS="17.11"
+ - DPDK_VERS="17.11.2"
matrix:
- CONF=""
- CONF="--disable-abi-compat"
commit 5028177e4e795305b514d7164ff882dcf1d3622b
Author: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Date: Tue Apr 24 11:53:05 2018 +0300
travis: fetch explicitly specified DPDK version
Use tag to fetch DPDK, rather than fetching top of corresponding branch.
This allows us to specify stable version and stop unnecessary playing
with the cache.
Signed-off-by: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Reviewed-by: Matias Elo <matias.elo(a)nokia.com>
Signed-off-by: Maxim Uvarov <maxim.uvarov(a)linaro.org>
diff --git a/.travis.yml b/.travis.yml
index 2f47ed79..70eff748 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -154,12 +154,7 @@ install:
fi
- gem install asciidoctor
- # DPDK pktio. Note that cache must be purged if dpdk version changes.
- - |
- CACHED_DPDK_VERS=`fgrep Version dpdk/pkg/dpdk.spec | cut -d " " -f 2`
- if [ "${CACHED_DPDK_VERS}" != "${DPDK_VERS}" ]; then
- rm -rf dpdk
- fi
+ # DPDK pktio. Cache will be updated automatically to ${DPDK_VERS}
- |
case "$CROSS_ARCH" in
"arm64")
@@ -193,8 +188,17 @@ install:
LIBDPDKEXT=a
fi
DPDK_TARGET="${DPDK_TARGET}gcc"
+ CACHED_DPDK_VERS=`fgrep Version dpdk/pkg/dpdk.spec | cut -d " " -f 2`
+ if [ ! -d dpdk -o "${CACHED_DPDK_VERS}" != "${DPDK_VERS}" ]; then
+ rm -rf dpdk
+ mkdir dpdk
+ pushd dpdk
+ git init
+ git -c advice.detachedHead=false fetch -q --depth=1 http://dpdk.org/git/dpdk-stable v${DPDK_VERS}
+ git checkout -f FETCH_HEAD
+ popd
+ fi
if [ ! -f "dpdk/${TARGET}/usr/local/lib/libdpdk.$LIBDPDKEXT" ]; then
- git -c advice.detachedHead=false clone -q --depth=1 --single-branch --branch=${DPDK_VERS} http://dpdk.org/git/dpdk-stable dpdk
pushd dpdk
git log --oneline --decorate
# AArch64 && ARMv7 fixup
-----------------------------------------------------------------------
Summary of changes:
.travis.yml | 20 ++++++++++++--------
test/validation/api/crypto/odp_crypto_test_inp.c | 2 ++
2 files changed, 14 insertions(+), 8 deletions(-)
hooks/post-receive
diff --git a/platform/linux-generic/odp_ipsec.c b/platform/linux-generic/odp_ipsec.c
index 782cbf45..7401f590 100644
--- a/platform/linux-generic/odp_ipsec.c
+++ b/platform/linux-generic/odp_ipsec.c
@@ -844,6 +844,7 @@ static int ipsec_out_tunnel_parse_ipv6(ipsec_state_t *state,
state->out_tunnel.ip_flabel = (ipv6hdr->ver_tc_flow &
_ODP_IPV6HDR_FLOW_LABEL_MASK) >>
_ODP_IPV6HDR_FLOW_LABEL_SHIFT;
+ state->ip_next_hdr = ipv6hdr->next_hdr;
return 0;
}
-----------------------------------------------------------------------
Summary of changes:
platform/linux-generic/odp_ipsec.c | 1 +
platform/linux-generic/test/mmap_vlan_ins/mmap_vlan_ins.sh | 4 ++--
2 files changed, 3 insertions(+), 2 deletions(-)
hooks/post-receive
--
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "".
The branch, master has been updated
via 6947621e1b3a3c73c3ee351325f505e5e191474f (commit)
from 29cb860583cb906bc16eddf9a4c98d6bb37333e5 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commit 6947621e1b3a3c73c3ee351325f505e5e191474f
Author: Josep Puigdemont <josep.puigdemont(a)linaro.org>
Date: Mon Apr 23 13:48:22 2018 +0200
linux-gen: fdserver: remove unnecessary locking
The locks in fdserver's operations don't serve any purpose, there is no
need to acquire a lock when registering a file descriptor to the server,
specially because the only place where the registering function is used
is already protected by another lock, and the same goes for
deregistering. Also, the fdserver handles requests sequentially.
On the other hand, removing the lock from the lookup function may return
a fd that is being deregistered, but this is not protecting us from
misusing it because the operation to be unregistered may be queued right
after the lookup request, at which point the fd is already invalid
anyway.
Signed-off-by: Josep Puigdemont <josep.puigdemont(a)linaro.org>
Reviewed-by: Bill Fischofer <bill.fischofer(a)linaro.org>
Signed-off-by: Maxim Uvarov <maxim.uvarov(a)linaro.org>
diff --git a/platform/linux-generic/odp_fdserver.c b/platform/linux-generic/odp_fdserver.c
index 0e9fb0e4..774fe360 100644
--- a/platform/linux-generic/odp_fdserver.c
+++ b/platform/linux-generic/odp_fdserver.c
@@ -39,7 +39,6 @@
*/
#include <odp_posix_extensions.h>
-#include <odp/api/spinlock.h>
#include <odp_internal.h>
#include <odp_debug_internal.h>
#include <odp_fdserver_internal.h>
@@ -78,9 +77,6 @@
ODP_DBG(fmt, ##__VA_ARGS__);\
} while (0)
-/* when accessing the client functions, clients should be mutexed: */
-static odp_spinlock_t *client_lock;
-
/* define the tables of file descriptors handled by this server: */
#define FDSERVER_MAX_ENTRIES 256
typedef struct fdentry_s {
@@ -288,23 +284,18 @@ int _odp_fdserver_register_fd(fd_server_context_e context, uint64_t key,
int command;
int fd;
- odp_spinlock_lock(client_lock);
-
FD_ODP_DBG("FD client register: pid=%d key=%" PRIu64 ", fd=%d\n",
getpid(), key, fd_to_send);
s_sock = get_socket();
- if (s_sock < 0) {
- odp_spinlock_unlock(client_lock);
+ if (s_sock < 0)
return -1;
- }
res = send_fdserver_msg(s_sock, FD_REGISTER_REQ, context, key,
fd_to_send);
if (res < 0) {
ODP_ERR("fd registration failure\n");
close(s_sock);
- odp_spinlock_unlock(client_lock);
return -1;
}
@@ -313,13 +304,11 @@ int _odp_fdserver_register_fd(fd_server_context_e context, uint64_t key,
if ((res < 0) || (command != FD_REGISTER_ACK)) {
ODP_ERR("fd registration failure\n");
close(s_sock);
- odp_spinlock_unlock(client_lock);
return -1;
}
close(s_sock);
- odp_spinlock_unlock(client_lock);
return 0;
}
@@ -334,22 +323,17 @@ int _odp_fdserver_deregister_fd(fd_server_context_e context, uint64_t key)
int command;
int fd;
- odp_spinlock_lock(client_lock);
-
FD_ODP_DBG("FD client deregister: pid=%d key=%" PRIu64 "\n",
getpid(), key);
s_sock = get_socket();
- if (s_sock < 0) {
- odp_spinlock_unlock(client_lock);
+ if (s_sock < 0)
return -1;
- }
res = send_fdserver_msg(s_sock, FD_DEREGISTER_REQ, context, key, -1);
if (res < 0) {
ODP_ERR("fd de-registration failure\n");
close(s_sock);
- odp_spinlock_unlock(client_lock);
return -1;
}
@@ -358,13 +342,11 @@ int _odp_fdserver_deregister_fd(fd_server_context_e context, uint64_t key)
if ((res < 0) || (command != FD_DEREGISTER_ACK)) {
ODP_ERR("fd de-registration failure\n");
close(s_sock);
- odp_spinlock_unlock(client_lock);
return -1;
}
close(s_sock);
- odp_spinlock_unlock(client_lock);
return 0;
}
@@ -380,19 +362,14 @@ int _odp_fdserver_lookup_fd(fd_server_context_e context, uint64_t key)
int command;
int fd;
- odp_spinlock_lock(client_lock);
-
s_sock = get_socket();
- if (s_sock < 0) {
- odp_spinlock_unlock(client_lock);
+ if (s_sock < 0)
return -1;
- }
res = send_fdserver_msg(s_sock, FD_LOOKUP_REQ, context, key, -1);
if (res < 0) {
ODP_ERR("fd lookup failure\n");
close(s_sock);
- odp_spinlock_unlock(client_lock);
return -1;
}
@@ -401,7 +378,6 @@ int _odp_fdserver_lookup_fd(fd_server_context_e context, uint64_t key)
if ((res < 0) || (command != FD_LOOKUP_ACK)) {
ODP_ERR("fd lookup failure\n");
close(s_sock);
- odp_spinlock_unlock(client_lock);
return -1;
}
@@ -409,7 +385,6 @@ int _odp_fdserver_lookup_fd(fd_server_context_e context, uint64_t key)
ODP_DBG("FD client lookup: pid=%d, key=%" PRIu64 ", fd=%d\n",
getpid(), key, fd);
- odp_spinlock_unlock(client_lock);
return fd;
}
@@ -421,27 +396,21 @@ static int stop_server(void)
int s_sock; /* server socket */
int res;
- odp_spinlock_lock(client_lock);
-
FD_ODP_DBG("FD sending server stop request\n");
s_sock = get_socket();
- if (s_sock < 0) {
- odp_spinlock_unlock(client_lock);
+ if (s_sock < 0)
return -1;
- }
res = send_fdserver_msg(s_sock, FD_SERVERSTOP_REQ, 0, 0, -1);
if (res < 0) {
ODP_ERR("fd stop request failure\n");
close(s_sock);
- odp_spinlock_unlock(client_lock);
return -1;
}
close(s_sock);
- odp_spinlock_unlock(client_lock);
return 0;
}
@@ -595,12 +564,6 @@ int _odp_fdserver_init_global(void)
pid_t server_pid;
int res;
- /* create the client spinlock that any client can see: */
- client_lock = mmap(NULL, sizeof(odp_spinlock_t), PROT_READ | PROT_WRITE,
- MAP_SHARED | MAP_ANONYMOUS, -1, 0);
-
- odp_spinlock_init(client_lock);
-
snprintf(sockpath, FDSERVER_SOCKPATH_MAXLEN, FDSERVER_SOCKDIR_FORMAT,
odp_global_data.shm_dir,
odp_global_data.uid);
-----------------------------------------------------------------------
Summary of changes:
platform/linux-generic/odp_fdserver.c | 45 ++++-------------------------------
1 file changed, 4 insertions(+), 41 deletions(-)
hooks/post-receive
--
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "".
The branch, master has been updated
via acc05760d5060d1782aa597e44c72ccb9a71b63b (commit)
from c440dfceff97526d2763383afd8da064faef3d0d (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commit acc05760d5060d1782aa597e44c72ccb9a71b63b
Author: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Date: Tue Apr 3 15:48:12 2018 +0300
validation: crypto: zero return code of odp_crypto_op/odp_crypto_op_enq
crypto_main test will accept odp_crypto_op/odp_crypto_op_enq
returning 0 meaning 0 packets were processed. Instead it
should mark test as failedin this case.
Fixes: https://bugs.linaro.org/show_bug.cgi?id=3763
Signed-off-by: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Reviewed-by: Bill Fischofer <bill.fischofer(a)linaro.org>
Signed-off-by: Maxim Uvarov <maxim.uvarov(a)linaro.org>
diff --git a/test/validation/api/crypto/odp_crypto_test_inp.c b/test/validation/api/crypto/odp_crypto_test_inp.c
index aa053dd5..676b9b12 100644
--- a/test/validation/api/crypto/odp_crypto_test_inp.c
+++ b/test/validation/api/crypto/odp_crypto_test_inp.c
@@ -200,7 +200,7 @@ static int alg_packet_op(odp_packet_t pkt,
op_params.hash_result_offset = plaintext_len;
rc = odp_crypto_op(&pkt, &out_pkt, &op_params, 1);
- if (rc < 0) {
+ if (rc <= 0) {
CU_FAIL("Failed odp_crypto_packet_op()");
return rc;
}
@@ -261,7 +261,7 @@ static int alg_packet_op_enq(odp_packet_t pkt,
op_params.hash_result_offset = plaintext_len;
rc = odp_crypto_op_enq(&pkt, &pkt, &op_params, 1);
- if (rc < 0) {
+ if (rc <= 0) {
CU_FAIL("Failed odp_crypto_op_enq()");
return rc;
}
-----------------------------------------------------------------------
Summary of changes:
test/validation/api/crypto/odp_crypto_test_inp.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
hooks/post-receive
--
--
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "".
The branch, master has been updated
via 24262a9aae62290dfd1a041d0bd5c6943270251d (commit)
via 7e355890905a9195ff1027377991b4134e285a03 (commit)
from 6947621e1b3a3c73c3ee351325f505e5e191474f (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commit 24262a9aae62290dfd1a041d0bd5c6943270251d
Author: Petri Savolainen <petri.savolainen(a)linaro.org>
Date: Tue Apr 24 15:53:59 2018 +0300
test: mmap_vlan_ins: wait for background process
Each 'make check' run was still leaving a mmap_vlan_ins
process behind. Wait until both processes (also the background
process) has finished before tearing down the interfaces.
Signed-off-by: Petri Savolainen <petri.savolainen(a)linaro.org>
Signed-off-by: Maxim Uvarov <maxim.uvarov(a)linaro.org>
diff --git a/platform/linux-generic/test/mmap_vlan_ins/mmap_vlan_ins.sh b/platform/linux-generic/test/mmap_vlan_ins/mmap_vlan_ins.sh
index ae263ee3..b0eb046b 100755
--- a/platform/linux-generic/test/mmap_vlan_ins/mmap_vlan_ins.sh
+++ b/platform/linux-generic/test/mmap_vlan_ins/mmap_vlan_ins.sh
@@ -69,8 +69,8 @@ plat_mmap_vlan_ins${EXEEXT} pktiop0p1 pcap:out=${PCAP_OUT} \
plat_mmap_vlan_ins${EXEEXT} pcap:in=${PCAP_IN} pktiop1p0 \
01:02:03:04:05:06 01:08:09:0a:0b:0c
-# Give both processes time to close before removing interfaces
-sleep 4
+# Wait both processes to exit before removing the interfaces
+wait $!
rm -f ${PCAP_OUT}
cleanup_pktio_env
commit 7e355890905a9195ff1027377991b4134e285a03
Author: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Date: Mon Apr 23 23:10:03 2018 +0300
linux-gen: ipsec: parse IPv6 next header in tunnel case
IPsec parsing code will fail to update next header field in internal
state in case of outbound tunnel processing of IPv6 packets.
Fixes: https://bugs.linaro.org/show_bug.cgi?id=3764
Signed-off-by: Dmitry Eremin-Solenikov <dmitry.ereminsolenikov(a)linaro.org>
Reviewed-by: Bill Fischofer <bill.fischofer(a)linaro.org>
Signed-off-by: Maxim Uvarov <maxim.uvarov(a)linaro.org>